﻿//   Copyright 2023 Esri
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at

//       https://www.apache.org/licenses/LICENSE-2.0

//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License. 

using ArcGIS.Desktop.Framework;
using ArcGIS.Desktop.Framework.Contracts;
using ArcGIS.Desktop.Mapping;
using System.Collections.Generic;
using System.Linq;

namespace TableAndGeometryControl
{
  internal class TableUtils
  {
    internal static string CrimesLayerName = "Crimes";

    internal static ITablePane GetTablePane(MapMember mapMember)
    {
      // check the open panes to see if it's open but just needs activating
      IEnumerable<ITablePane> tablePanes = FrameworkApplication.Panes.OfType<ITablePane>();

      var tablePane = tablePanes.FirstOrDefault(tp => tp.MapMember == mapMember);
      return tablePane;
    }

    internal static IExternalTablePane GetExternalTablePanes(string caption)
    {
      IEnumerable<IExternalTablePane> extTablePanes = FrameworkApplication.Panes.OfType<IExternalTablePane>();

      var tablePane = extTablePanes.FirstOrDefault(tp => tp.Caption == caption);
      return tablePane;
    }

    internal static ITablePane ActivateTablePane(MapMember mapMember)
    {
      var tablePane = GetTablePane(mapMember);

      var pane = tablePane as Pane;
      pane?.Activate();
      return tablePane;
    }
  }
}
