﻿//   Copyright 2023 Esri
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at

//       https://www.apache.org/licenses/LICENSE-2.0

//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License. 

using ArcGIS.Desktop.Framework.Contracts;
using ArcGIS.Desktop.Framework.Dialogs;
using ArcGIS.Desktop.Mapping;
using System;
using System.Collections.Generic;
using System.Linq;

namespace TableAndGeometryControl
{
  internal class TableViewHideColumnsButton : Button
  {
    private bool _showCustomization = false;

    protected override void OnClick()
    {
      _showCustomization = !_showCustomization;
      try
      {
        var layer = MapView.Active.Map.GetLayersAsFlattenedList().
                        Where(l => l.Name == TableUtils.CrimesLayerName).FirstOrDefault();
        if (layer == null)
          return;

        TableUtils.ActivateTablePane(layer);

        var tableView = TableView.Active;
        if (tableView == null)
          return;
        
        if (_showCustomization)
        {
          // set visible and hidden columns
          tableView.ShowAllFields();
          tableView.SetHiddenFields(new List<string>() {
            "Shape", "Address", "Neighborhood",
            "Police_Precinct", "Police_District",  
            "X_Coordinate", "Y_Coordinate", "Offense_Type"});
        }
        else
        {
          tableView.ShowAllFields();
        }
      }
      catch (Exception ex)
      {
        MessageBox.Show($@"Error: {this} {ex}");
      }
    }
  }
}
