﻿//   Copyright 2023 Esri
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at

//       https://www.apache.org/licenses/LICENSE-2.0

//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License. 

using ArcGIS.Desktop.Framework.Contracts;
using ArcGIS.Desktop.Framework.Threading.Tasks;
using ArcGIS.Desktop.Mapping;
using System.Collections.Generic;
using System.Linq;

namespace TableAndGeometryControl
{
  internal class TableViewMoveTo : Button
  {
    protected override void OnClick()
    {
      var layer = MapView.Active.Map.GetLayersAsFlattenedList().
                      Where(l => l.Name == TableUtils.CrimesLayerName).FirstOrDefault();
      if (layer == null)
        return;

      var tableView = TableView.Active;
      if (tableView == null)
        return;

      QueuedTask.Run(() =>
      {
        var oid = 267;
        var rowIdx = tableView.GetRowIndex(oid, false);
        tableView.BringIntoView(rowIdx);

        var rowIndexes = new List<long>() { rowIdx, rowIdx+1 };
        tableView.Select(rowIndexes, false);

        MapView.Active.ZoomToSelected();
      });
    }
  }
}
